import "./index.css";
import React, { useState, useEffect } from "react";
import Button from "commonComponents/Button";

import Dropdown from "commonComponents/Dropdown";

const Modal = ({ showModal, modalData, toggleModal, onSave }) => {
  const [modalState, setModalState] = useState({});

  useEffect(() => {
    if (!Object.keys(modalState).length) {
      let obj = {};
      const state = modalData.content.map((item) => (obj[item.name] = null));
      setModalState(obj);
    }
  }, [modalData.content]);

  const handleInputChange = (val, key) => {
    setModalState((modalState) => {
      return {
        ...modalState,
        [key]: val,
      };
    });
  };
  return (
    <div
      id="myModal"
      className="modal"
      style={{ display: showModal ? "block" : "none" }}
    >
      <div className="modal-content">
        <span className="close" onClick={toggleModal}>
          &times;
        </span>
        {modalData.content.map((config) => {
          if (config.enabled) {
            switch (config.type) {
              case "dropdown":
                return (
                  <div style={{ marginBottom: "10px" }}>
                    <p style={{ margin: "10px 0px" }}>{config.label[0]}</p>
                    <Dropdown
                      useMenuPortalTarget={false}
                      key={config.name}
                      width={100}
                      // dropdownStyles={dropdownStyles}
                      // dropdownTitleStyles={dropdownTitleStyles}
                      handleValueChange={(v) =>
                        handleInputChange(v.value, config.name)
                      }
                      options={config.options}
                      value={
                        modalState[config.name] ? modalState[config.name] : {}
                      }
                    />
                  </div>
                );
                break;
              case "input":
                return (
                  <div style={{ marginBottom: "10px" }}>
                    <p style={{ margin: "10px 0px" }}>{config.label[0]}</p>
                    <textarea
                      style={{
                        width: "100%",
                        height: "42px",
                        borderRadius: "4px",
                        backgroundColor: "transparent",
                        border: "1px solid rgb(43, 53, 83)",
                      }}
                      onChange={(e) =>
                        handleInputChange(e.target.value, config.name)
                      }
                      value={
                        modalState[config.name] ? modalState[config.name] : ""
                      }
                    />
                  </div>
                );
                break;
              case "radio":
                return (
                  <div style={{ marginBottom: "10px" }}>
                    <p style={{ margin: "10px 0px" }}>{config.label[0]}</p>
                    {config.options.map((item) => (
                      <>
                        <input
                          type="radio"
                          name={config.name}
                          value={item}
                          onClick={() => handleInputChange(item, config.name)}
                        />
                         <label for="css">{item}</label>
                      </>
                    ))}
                  </div>
                );
                break;

              default:
                break;
            }
          }
        })}
        <div>
          <Button
            size="sm"
            onClick={() => onSave(modalState)}
            buttonText="Save"
          />
        </div>
      </div>
    </div>
  );
};

export default Modal;
