import React from "react";
import Draggable from "react-draggable";
import { each, isEmpty } from "lodash";
import Dropdown from "commonComponents/Dropdown";
import Button from "@material/react-button";
import styled from "styled-components";

const classes = {
  wrapper: {
    overflow: "auto",
    // maxWidth: '75vw'
  },
  actionButtons: {
    display: "flex",
    justifyContent: "space-evenly",
  },
  canvas: {
    display: "flex",
  },
  draggable: {
    zIndex: 999,
    position: "fixed",
    overflow: "scroll",
    whiteSpace: "pre-wrap",
    maxHeight: "80vh",
    border: "1px",
    // background: "light" === "light" ? "white" : "#2e2e31",
    // boxShadow: "light" === "light" && "10px 10px 50px rgb(0 0 0 / 15%)",
    // left: "light" === "light" && "30%",
    // "& h4": {
    //   color: "light" === "light" && "#767676",
    // },
    // "& label": {
    //   color: "light" === "light" && "#767676 !important",
    // },
    // "& input": {
    //   color: "light" === "light" && "#767676 !important",
    // },
  },
  dropdown: {
    "& h4": {
      fontSize: "14px",
      // fontSize: "light" === "light" && "14px !important",
      // fontWeight: "light" === "light" && "unset !important",
    },
  },
  selectedCrops: {
    display: "flex",
    flexFlow: "row wrap",
  },
  cropDetails: {
    // width: 200,
    // height: "fit-content",
    // padding: 10,
    // overflow: "auto",
    fontSize: "14px",
  },
  item: {
    width: 260,
    display: "grid",
    gridTemplateColumns: "140px 140px",
    "& h4": {
      whiteSpace: "pre-line",
      wordBreak: "break-all",
    },
    "& a": {
      // color: "light" === "light" ? "blue" : "aqua",
    },
    "& img": {
      maxHeight: 160,
      maxWidth: "100%",
      paddingTop: 10,
    },
  },
  saveButton: {
    background: "#e14eca",

    boxShadow:
      "0 2px 2px 0 rgb(156 39 176 / 14%), 0 3px 1px -2px rgb(156 39 176 / 20%), 0 1px 5px 0 rgb(156 39 176 / 12%)",
    backgroundSize: "210% 210%",
    backgroundColor: "#e14eca",
    backgroundImage: "linear-gradient(to bottom left,#e14eca,#ba54f5,#e14eca)",
    backgroundPosition: "100% 0",
    padding: "5px 10px",

    border: "none",
    borderRadius: "0.2rem",
    fontSize: "12px",
    fontWeight: "400",
    letterSpacing: "0",
    textTransform: "uppercase",
    color: "#FFFFFF",
    border: "none",
    cursor: "pointer",
    margin: "0.3125rem 1px",

    position: "relative",
    minWidth: "auto",
    minHeight: "auto",
    textAlign: "center",
    transition:
      "box-shadow 0.2s cubic-bezier(0.4, 0, 1, 1), background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1)",

    whiteSpace: "nowrap",
    willChange: "box-shadow, transform",
    touchAction: "manipulation",
    borderRadius: "3px",
    "&:hover": {
      background: "#efefef",
    },
  },
};

const StyledInput = styled("input")`
  &:hover {
    outline: ${(props) => (props.theme !== "light" ? "#fff" : "#767676")};
  }
  &:focus-visible {
    outline: none;
  }
`;

const FixFacing = ({
  selectedBoxes,
  fixFacingFilters,
  handleProductFilterChange,
  filterValues,
  resetFilters,
  saveFilters,
  theme,
  forUpdationBoxes,
  stickerPrice,
  setStickerPrice,
}) => {
  const isParentSelected = (parentFilter, dependentOn, filter) => {
    const concernedFilter = parentFilter.find(
      (item) => item.key === dependentOn
    );
    return (
      concernedFilter &&
      isEmpty(filterValues[concernedFilter.label]) &&
      filter.dependent_on
    );
  };

  const getSKUList = (parentFilter, dependentOn) => {
    const concernedFilter = parentFilter.find(
      (item) => item.key === dependentOn
    );
    const rawOptions = concernedFilter.options.reduce((optionsList, option) => {
      const modifiedSKUList = option.sku.map((item) => {
        let skuOption = { ...item };
        skuOption.parentOption = { label: option.label, value: option.value };
        return skuOption;
      });
      optionsList.push(...modifiedSKUList);
      return optionsList;
    }, []);

    const optionsList = [
      ...new Map(rawOptions.map((item) => [item["value"], item])).values(),
    ];
    return optionsList;
  };

  const getFilterOptions = (parentFilter, dependentOn) => {
    const concernedFilter = parentFilter.find(
      (item) => item.key === dependentOn
    );
    const brandOption = filterValues[concernedFilter.label]
      ? concernedFilter.options.find(
          (item) => item.value === filterValues[concernedFilter.label].value
        )
      : { sku: [] };
    const optionsList = brandOption.sku.map((item) => {
      return {
        ...item,
        parentOption: { label: brandOption.label, value: brandOption.value },
      };
    });
    return optionsList;
  };

  const isFilterSelected = Object.keys(filterValues)
    .map((item) => !isEmpty(filterValues[item]))
    .includes(true);

  return (
    <Draggable>
      <div
        className="cropDetailsTooltip prodcuctFacingToolTip"
        style={{
          top: 10,
          left: 10,
          backgroundColor: theme === "light" && "#fff",
          color: theme === "light" && "#767676",
        }}
      >
        <div style={classes.cropDetails}>
          <div style={{ fontSize: "12px" }}>
            {/* <Typography size={12} weight={400}> */}
            {`Total crops selected ${forUpdationBoxes.length}`}
            {/* </Typography> */}
          </div>
          {fixFacingFilters && (
            <>
              <div style={{ ...classes.dropdown, margin: "10px 0px" }}>
                {Object.keys(fixFacingFilters.data).map((item) => {
                  return fixFacingFilters.data[item].map((filter) => {
                    const isDisabled = filter.controlling_filter
                      .map((item) => {
                        return !isEmpty(filterValues[item]);
                      })
                      .includes(true);
                    return (
                      <Dropdown
                        theme={theme}
                        useMenuPortalTarget={false}
                        key={filter.label}
                        width={100}
                        title={filter.label}
                        // dropdownStyles={dropdownStyles}
                        // dropdownTitleStyles={dropdownTitleStyles}
                        handleValueChange={(v) =>
                          handleProductFilterChange({
                            value: v,
                            id: filter.label,
                            productFilter: fixFacingFilters.data[item],
                            dependentOn: filter.dependent_on,
                            currentFilter: filter,
                          })
                        }
                        options={
                          isParentSelected(
                            fixFacingFilters.data[item],
                            filter.dependent_on,
                            filter
                          )
                            ? getSKUList(
                                fixFacingFilters.data[item],
                                filter.dependent_on
                              )
                            : filter.dependent_on
                            ? getFilterOptions(
                                fixFacingFilters.data[item],
                                filter.dependent_on
                              )
                            : [...filter.options]
                        }
                        isDisabled={
                          isDisabled ||
                          Object.keys(forUpdationBoxes || {}).length < 1
                        }
                        value={
                          filterValues[filter.label]
                            ? filterValues[filter.label]
                            : {}
                        }
                      />
                    );
                  });
                })}
                <div
                  style={{ color: theme === "light" ? "#3f3f3f" : "inherit" }}
                >
                  Price
                </div>
                <StyledInput
                  theme={theme}
                  onChange={(e) => setStickerPrice(e.target.value)}
                  id="price"
                  value={stickerPrice}
                  type="text"
                  label="Price"
                  margin="normal"
                  colorTheme="dark"
                  style={{
                    height: "36px",
                    border:
                      theme === "light"
                        ? " 1px solid #c7c7c7"
                        : "1px solid #2b3553",
                    borderRadius: "4px",
                    backgroundColor: "transparent",
                    color: theme === "light" ? "#767676" : "#ffffff99",
                  }}
                  //   fullWidth
                  variant="outlined"
                />
              </div>
            </>
          )}
        </div>
        <div style={classes.actionButtons}>
          <Button
            onClick={saveFilters}
            className="coloredButtons"
            disabled={
              forUpdationBoxes && isFilterSelected
                ? forUpdationBoxes.length < 1
                : true
            }
            style={classes.saveButton}
          >
            Save
          </Button>
          <Button
            className="coloredButtons"
            onClick={resetFilters}
            style={classes.saveButton}
          >
            Reset
          </Button>
        </div>
      </div>
    </Draggable>
  );
};

export default FixFacing;
