import React, { useEffect, useRef, useState } from "react";
import Draggable from "react-draggable";
import SvgRect from "commonComponents/svgRect";
import ImageRenderer from "commonComponents/imageRenderer";
import { ShelfDisplayConstants } from "utils/constants";
const { minimapImageHeight, shelfImageHeight } = ShelfDisplayConstants;
const Index = React.memo(
  ({
    images,
    boundingBoxes,
    setMinPos,
    minPos,
    scrollValue,
    setScrollLeft,
    showAnchor,
    loading,
    minimapDraggableWidth,
    shelfWidth,
    selectedBoxes,
    dynamicCheckboxes,
    forUpdationBoxes,
    isTse,
  }) => {
    const dargRef = useRef();
    const divRef = useRef();
    const [anchorWidth, setAnchorWidth] = useState(0);
    useEffect(() => {
      if (!showAnchor) {
        setAnchorWidth(
          (minimapDraggableWidth * minimapImageHeight) / shelfImageHeight
        );
      } else {
        setAnchorWidth((shelfWidth * minimapImageHeight) / shelfImageHeight);
      }
    }, [showAnchor]);
    useEffect(() => {
      if (!minPos)
        divRef.current.scrollLeft =
          (minimapImageHeight * scrollValue) / shelfImageHeight;
    }, [scrollValue]);

    return (
      <div
        ref={divRef}
        className="canvasWrapper"
        style={{
          width: shelfWidth,
          height: minimapImageHeight,
          scrollbarWidth: "none",
        }}
      >
        {
          <Draggable
            axis="x"
            ref={dargRef}
            bounds={{
              left: 0,
              right:
                (minimapDraggableWidth * minimapImageHeight) /
                  shelfImageHeight -
                (shelfWidth * minimapImageHeight) / shelfImageHeight,
            }}
            onDrag={(e) => {
              setScrollLeft(
                (dargRef.current.state.x * shelfImageHeight) /
                  minimapImageHeight
              );
            }}
            onStop={() => setMinPos(false)}
            onStart={() => setMinPos(true)}
            position={{
              x: minPos
                ? dargRef.current.state.x
                : (minimapImageHeight * scrollValue) / shelfImageHeight,
              y: 0,
            }}
          >
            <svg
              className="svgComponent miniMapAnchor"
              style={{
                width: anchorWidth,
              }}
            >
              <rect
                x={0}
                y={0}
                width={anchorWidth}
                height={"100%"}
                stroke={"yellow"}
                strokeWidth="4px"
                fill="none"
              ></rect>
            </svg>
          </Draggable>
        }
        {images.map((img, index) => (
          <div className="miniMapImagesWrapper" key={index}>
            <div
              style={{
                height: minimapImageHeight,
                width: (minimapImageHeight * img.width) / img.height,
                // display: "inline-flex",
              }}
            >
              <SvgRect
                boundingBoxes={boundingBoxes}
                minimap={true}
                img={img}
                dynamicCheckboxes={dynamicCheckboxes}
                selectedBoxes={selectedBoxes}
                forUpdationBoxes={forUpdationBoxes}
                isTse={isTse}
              />
              {/* <SvgPolygon showPosm={showPosm} img={img} minimap={true} /> */}
              <ImageRenderer img={img.scaled_img || img.path} />
            </div>
          </div>
        ))}
      </div>
    );
  }
);

export default Index;
