import React, { useCallback, useEffect, useState } from "react";
import ShelfImageDisplay from "./Shelf";
import Minimap from "./Minimap";
import "./styles.css";
import axios from "axios";
import loader from "assets/loader.gif";
import ErrorBoundary from "./ErrorBoundary";
import Table from "./Table";
import metadata from "metadata";
import ContainerDimensions from "react-container-dimensions";
import { capitalize } from "lodash";

import DetailsTooltip from "commonComponents/detailsTooltip";

import ShelfHeader from "./ShelfHeader";
import ImageViewer from "commonComponents/ImageViewer/imageViewer";
import Toolbar from "features/Toolbar";
import FixFacing from "features/FixFacing";
import ToggleComponent from "commonComponents/Toggle";
import { sessionMock } from "sessionMock.js";
import { filterData } from "mockData.js";
import { response } from "utils/constants";

const ShelfVisualizer = ({ multiSelectionEnabled = false }) => {
  const [visibleBoxes, showAllBoxes] = useState(false);
  const [selectedVariants, setSelectedVariants] = useState([]);
  const [isZoomEnabled, enableZoom] = useState(false);
  const [scrollValue, setScrollValue] = useState(0);
  const [minPos, setMinPos] = useState(false);
  const [selectedBoxes, setSelectedBoxes] = useState([]);
  const [forUpdationBoxes, setForUpdationBoxes] = useState([]);

  const [loading, setLoading] = useState(false);

  // for dynamic checkboxes
  const [dynamicCheckboxes, setDynamicCheckboxes] = useState(null);
  const [actionKeysMapping, setActionKeysMapping] = useState(null);
  const [sessionData, setSessionData] = useState(null);
  const [fixFacingFilters, setFixFacingFilters] = useState(null);
  const [tableData, setTableData] = useState(null);
  const [allVariantsSelected, setAllVariantsSelected] = useState(false);
  const [imageBoundingBoxes, setBoundingBoxes] = useState([]);
  const [variantBoundingBoxes, setVariantBoundingBoxes] = useState([]);
  const [showAnchor, setShowAnchor] = useState(false);
  const [showCropDetails, setShowCropDetails] = useState({
    show: false,
    details: null,
    type: "",
  });
  const [minimapDraggableWidth, setMinimapDraggableWidth] = useState(null);
  const [defaultAnchorPosition, setDefaultAnchorPosition] = useState(0);
  const [imagesSetWidth, setImagesSetWidth] = useState(null);
  const [filters, setFilters] = useState({
    fl_placement: "shelf",
    fl_category: "fabric-enhancer",
    fl_store_brand: "ism-club",
    fl_store: "48/01/036519",
    fl_dropdown_date: "09/02/2022",
    fl_type: "shelf",
    // fl_placement: "display",
    // fl_category: "fabric-enhancer",
    // fl_store_brand: "borma-dakota",
    // fl_store: "48/01/035824",
    // fl_dropdown_date: "02/03/2022",
  });
  const [filterValues, setFilterValues] = useState({});

  const [inclusion, setInclusion] = useState(true);
  const [showModal, setShowModal] = useState(false);
  const [imageUrl, setImageUrl] = useState("");
  const [tableTabs, setTableTabs] = useState([]);
  const [activeTab, setActiveTab] = useState(null);
  const [isTse, toggleTSE] = useState(false);
  const [theme, setTheme] = useState("dark");
  const [stickerPrice, setStickerPrice] = useState("");

  const [toolbarState, setToolbarState] = useState({});

  const ignoreKeys = ["color", "min", "max", "delta"];

  const toggleModal = () => {
    setShowModal((showModal) => !showModal);
    if (showModal) {
      setImageUrl("");
    }
  };

  const onClickImage = (url) => {
    setShowModal(true);

    setImageUrl(url);
  };

  useEffect(() => {
    if (sessionData?.store_explorer_settings) {
      const checkboxes = sessionData.store_explorer_settings;
      // create empty object for checkboxes state
      let dynamicCheckboxState = {};
      // create an array for all the BBoxes
      let allBoudingBoxes = [];
      // mapping objevt for action keys
      let actionKeysObject = {};
      // loop and create array
      sessionData.variants.forEach(
        (va) => (allBoudingBoxes = [...allBoudingBoxes, ...va.bounding_boxes])
      );
      Object.keys(checkboxes).map((label) => {
        if (checkboxes[label].enable === true) {
          // if the checkbox enabled, create a state with false as value
          if (checkboxes[label].for === "toggle_boxes") {
            //  check for the checkbox's action type
            const key = checkboxes[label].action_key;
            // filter bounding boxes which has values for enabled checkboxes
            let tempArray = allBoudingBoxes.filter((b) => b[key]);
            actionKeysObject[key] = tempArray;
          }
          return (dynamicCheckboxState[label] = false);
        }
      });

      setActionKeysMapping(actionKeysObject);

      setDynamicCheckboxes(dynamicCheckboxState);
    }
  }, [sessionData]);

  useEffect(() => {
    if (
      selectedVariants.length &&
      sessionData?.variants?.length &&
      selectedVariants.length !== sessionData?.variants?.length
    ) {
      setAllVariantsSelected(false);
    } else {
      setAllVariantsSelected(true);
    }
  }, [selectedVariants]);
  useEffect(() => {
    if (selectedVariants.length) {
      setScrollLeft(imagesSetWidth[Object.keys(imageBoundingBoxes)[0]]);
    }
  }, [selectedVariants]);

  const [scrolLeft, setScrollLeft] = useState(0);

  // method to handle bBox click
  const onClickBoundingBox = useCallback(
    (el, hover) => {
      if (isTse && !hover) {
        if (toolbarState["viewInfo"]) {
          let newState = [...forUpdationBoxes];
          const selectedBox = forUpdationBoxes.find(
            (item) => item.id === el.id
          );
          if (selectedBox) {
            const filteredBoxes = newState.filter((box) => box.id !== el.id);
            setForUpdationBoxes(filteredBoxes);
          } else {
            newState.push({
              photoID: el.photoID,
              id: el.id,
              originalColor: el.color,
            });
            setForUpdationBoxes(newState);
          }
        } else {
          let newState = [...selectedBoxes];
          const selectedBox = newState.find((item) => item.id === el.id);
          if (selectedBox?.inclusion === !toolbarState["inclusion"]) {
            const filteredBoxes = newState.filter((box) => box.id !== el.id);
            setSelectedBoxes(filteredBoxes);
          } else {
            const test = newState.filter((box) => box.id !== el.id);
            test.push({
              photoID: el.photoID,
              id: el.id,
              inclusion: !toolbarState["inclusion"],
              originalColor: el.color,
            });
            setSelectedBoxes(test);
          }
        }
      } else {
        // to show only details of the bouding box?
        if (
          showCropDetails.show &&
          showCropDetails.details.cropId === el.id &&
          !hover
        ) {
          setShowCropDetails({
            show: false,
            details: null,
            type: "",
          });
          setSelectedBoxes([]);
        } else {
          // required for changing border color
          if (!isTse) {
            setSelectedBoxes([
              {
                photoID: el.photoID,
                id: el.id,
              },
            ]);
          }
          const variantDetails = sessionData.variants.filter(
            (variant) =>
              variant.bounding_boxes.filter(
                (boduningBox) => boduningBox.id === el.id
              ).length > 0
          );

          setShowCropDetails({
            show: true,
            type: "boundingBox",
            details: {
              ...variantDetails[0],
              ...{
                cropId: el.id,
                imageUrl: sessionData.images.filter(
                  (image) => image.id === el.photoID
                )[0],
              },
            },
          });
        }
      }
    },
    [
      selectedBoxes,
      selectedVariants,
      forUpdationBoxes,
      sessionData,
      toolbarState["inclusion"],
      toolbarState["viewInfo"],
    ]
  );

  useEffect(() => {
    let newState = [...selectedBoxes];
    if (!toolbarState["viewInfo"]) {
      // clear forUpdation state
      setForUpdationBoxes([]);
    }
  }, [toolbarState["viewInfo"]]);

  // console.log(selectedBoxes);

  // methond to handle POSM click
  const onClickPolygon = useCallback((el) => {
    // to show only details of the bouding box?
    if (showCropDetails.show) {
      setShowCropDetails({
        show: false,
        details: null,
        type: "",
      });
    } else {
      setShowCropDetails({
        show: true,
        type: "POSM",
        details: {
          details: [{ type: el.type, brand: el.brand }],
        },
      });
    }
  });

  // handle table header banner checkbox clicking
  const handleCheckBoxClicked = (type, filter) => {
    // state object
    const checkBoxesState = { ...dynamicCheckboxes };
    // set the state value to false
    checkBoxesState[type] = !checkBoxesState[type];

    if (filter.for === "toggle_boxes") {
      setSelectedVariants([]);
      setAllVariantsSelected(false);

      if (
        checkBoxesState["toggle_boxes"] &&
        checkBoxesState["toggle_boxes"].length
      ) {
        if (checkBoxesState["toggle_boxes"].includes(filter.action_key)) {
          checkBoxesState["toggle_boxes"] = checkBoxesState[
            "toggle_boxes"
          ].filter((value) => value != filter.action_key);
        } else {
          checkBoxesState["toggle_boxes"] = [
            ...checkBoxesState["toggle_boxes"],
            filter.action_key,
          ];
        }
      } else {
        checkBoxesState["toggle_boxes"] = [filter.action_key];
      }
      if (
        !checkBoxesState["toggle_boxes"] ||
        checkBoxesState["toggle_boxes"].length === 0
      ) {
        setBoundingBoxes({});
      }

      // create an object with PhotoId as keys and selected action_keys

      let boudingBoxesObject = {};
      const colorConst = {
        is_in_overlap: "aqua",
        is_exclusion: "yellow",
        is_in_eye_level: "magenta",
      };
      checkBoxesState["toggle_boxes"].map((action_key) =>
        actionKeysMapping[action_key].forEach((bb) => {
          const boundingBox = { ...bb };
          boundingBox.color = colorConst[action_key]
            ? colorConst[action_key]
            : boundingBox.color;
          if (boudingBoxesObject[boundingBox.photoID]) {
            boudingBoxesObject[boundingBox.photoID] = [
              ...boudingBoxesObject[boundingBox.photoID],
              boundingBox,
            ];
          } else {
            boudingBoxesObject[boundingBox.photoID] = [boundingBox];
          }
        })
      );
      setBoundingBoxes(boudingBoxesObject);
    }

    setDynamicCheckboxes(checkBoxesState);
  };

  // method to create boundingBoxes and tableData
  useEffect(() => {
    if (sessionData?.images.length > 0) {
      // constructing table columns and rows structure accepted by ag-grid
      // will be moved to dashboard app
      const columns = sessionData?.variants[0]?.details.reduce((accu, item) => {
        Object.keys(item).map((item, index) => {
          let obj = {};
          obj["field"] = item;
          obj["title"] = capitalize(item);
          if (item === "packshot" || item === "Promotional Crop") {
            obj["cellRenderer"] = "imageRenderer";
            obj.cellRendererParams = { showModal, onClickImage };
          } else {
            obj["cellRenderer"] = "textRenderer";
          }
          obj["cellStyle"] = function () {
            return {
              alignItems: "center",
              display: "flex",
              whiteSpace: "pre-wrap",
              lineHeight: "20px",
            };
          };
          obj["resizable"] = "true";
          if (!ignoreKeys.includes(item)) {
            accu.push(obj);
          }
        });
        return accu;
      }, []);

      const rows = sessionData.variants.reduce((tableRows, variant) => {
        let obj = {};
        if (variant.details) {
          variant.details.map((item) => (obj = { ...obj, ...item }));
        }
        obj.id = variant.id;
        obj.rowHeight = 100;
        tableRows.push(obj);

        return tableRows;
      }, []);
      setTableData([
        { label: "Table 1", columns, rows },
        { label: "Table 2", columns, rows },
      ]);

      // segregating bBoxes based on variant ids (will be used on toggling bBoxes from table)
      setVariantBoundingBoxes(
        sessionData?.variants.reduce((vBBoxes, variant) => {
          vBBoxes[variant.id] = variant.bounding_boxes;
          return vBBoxes;
        }, {})
      );
    }
  }, [sessionData]);

  useEffect(() => {
    if (tableData?.length) {
      const tabValues = tableData.map((item) => item.label);
      setTableTabs(tabValues);
    }
  }, [tableData]);

  const resetComponent = () => {
    showAllBoxes(false);

    enableZoom(false);
    setScrollValue(0);
    setScrollLeft(0);
    setSessionData(null);
    setShowCropDetails({
      show: false,
      details: null,
      type: "",
    });
    setSelectedBoxes([]);
    setSelectedVariants([]);
    setVariantBoundingBoxes([]);
    setBoundingBoxes([]);
  };

  const handleSubmit = (e) => {
    e.preventDefault();

    // block to reset booleans to initial state on new API call
    // will be removed from the library and will be based on loading and fetching states coming from the app
    // ** //
    resetComponent();
    setLoading(true);
    let obj = { ...toolbarState };
    toolbarConfig.map((item) => (obj[item.name] = false));
    setToolbarState(obj);
    // ** //

    let params = {};
    if (isTse) {
      params = {
        ...filters,
        test: isTse,
      };
    } else {
      params = {
        ...filters,
      };
    }

    axios({
      method: "GET",
      headers: {
        Authorization: `token ${localStorage.getItem("authToken")} `,
      },
      url: "https://pg-indo.infiviz.ai/api/v1/get_store_photos/",
      params,
    }).then((res) => {
      setLoading(false);
      setSessionData(res.data.data);
    });
    // setSessionData(sessionMock);
    // setFixFacingFilters(filterData);

    axios({
      method: "GET",
      headers: {
        Authorization: `token ${localStorage.getItem("authToken")} `,
      },
      url: "https://pg-indo.infiviz.ai/api/v1/product_filter/",
      params: { fl_category: filters.fl_category },
    }).then((res) => {
      setFixFacingFilters(res.data);
    });
  };

  // method to handle checkbox click from table
  const onRowSelect = (val) => {
    let selectedValues = [...selectedVariants];
    let existingImagesBBoxes = { ...imageBoundingBoxes };

    // reset details tooltip
    // **

    if (showCropDetails.type === "boundingBox") {
      setShowCropDetails({
        show: false,
        details: null,
        type: "",
      });
      // if multiple selection is enabled then keep the selected array, if not we can reset the array
      if (!multiSelectionEnabled) {
        setSelectedBoxes([]);
      }
    }
    // **

    if (selectedVariants.includes(val.id)) {
      const itemIndex = selectedValues.indexOf(val.id);
      const unselectedBBoxes = variantBoundingBoxes[val.id];
      // remove selected variant id from selectedVariantsList
      selectedValues.splice(itemIndex, 1);
      // logic to remove concerned variantBBoxes from imagesIDBoxes
      unselectedBBoxes.map((box) => {
        // find the photoID group the box belongs to
        const changesToImageBBoxes = existingImagesBBoxes[box.photoID];
        // find index of the box in photoID group
        const indexOfBoxToRemove = changesToImageBBoxes.findIndex(
          (item) => item.id === box.id
        );

        // remove the box from photoID group
        if (indexOfBoxToRemove >= 0) {
          changesToImageBBoxes.splice(indexOfBoxToRemove, 1);
        }
        if (!(existingImagesBBoxes || {})[box.photoID]?.length) {
          delete existingImagesBBoxes[box.photoID];
        }
      });
    } else {
      // add selected variant id to selectedVariantsList
      selectedValues.push(val.id);
      const selectedBBoxes = variantBoundingBoxes[val.id];
      // logic to add  concerned variantBBoxes from imagesIdBoxes
      selectedBBoxes.map((box) => {
        // if photoID of box exists in list, push to the photoID group
        if (existingImagesBBoxes[box.photoID]) {
          const changesToImageBBoxes = existingImagesBBoxes[box.photoID];
          changesToImageBBoxes.push(box);
        } else {
          // else assign a new key for that photoID and add box to that
          existingImagesBBoxes[box.photoID] = [box];
        }
      });
    }

    setBoundingBoxes(existingImagesBBoxes);
    setSelectedVariants(selectedValues);
  };

  // method to toggle all bounding boxes
  const toggleAllBoxes = () => {
    showAllBoxes((visibleBoxes) => !visibleBoxes);
    // reset details tooltip
    // **
    if (showCropDetails.type === "boundingBox") {
      setShowCropDetails({
        show: false,
        details: null,
        type: "",
      });
      // if multiple selection is enabled then keep the selected array, if not we can reset the array
      if (!multiSelectionEnabled) {
        setSelectedBoxes([]);
      }
    }
    // **
    if (visibleBoxes) {
      // remove all bBoxes on clicking hide
      setBoundingBoxes({});
      setSelectedVariants([]);
      setSelectedBoxes([]);
    } else {
      setSelectedVariants(Object.keys(variantBoundingBoxes));
      // add all bBoxes on clicking show
      // segregating bBoxes based on their photoIds
      setBoundingBoxes(
        sessionData?.variants.reduce((accu, variant) => {
          variant.bounding_boxes.map((box) => {
            if (!(accu || {})[box.photoID]) {
              accu[box.photoID] = [];
            }
            accu[box.photoID].push(box);
          });
          return accu;
        }, {})
      );
    }
  };

  const toggleInclusion = () => {
    setInclusion((inclusion) => !inclusion);
  };

  const onClickSave = () => {
    console.log("save", selectedBoxes);
  };

  const [showInfoModal, setShowInfoModal] = useState(false);

  const toggleInfo = () => {
    setShowInfoModal((showInfoModal) => !showInfoModal);
  };

  const toggleToolbarModal = (key) => {
    setToolbarState((toolbarState) => {
      return {
        ...toolbarState,
        [key]: !toolbarState[key],
      };
    });
  };

  const toggleToolbarCheckbox = (key) => {
    setToolbarState((toolbarState) => {
      return {
        ...toolbarState,
        [key]: !toolbarState[key],
      };
    });
  };

  const toggleToolbarSwitch = (key) => {
    setToolbarState((toolbarState) => {
      return {
        ...toolbarState,
        [key]: !toolbarState[key],
      };
    });
  };

  const handleInclusionSave = () => {
    setSelectedBoxes([]);
    //  methodFromParent(selectedBoxes)
    const newState = [...selectedBoxes];
    const inclusionBoxes = newState.filter((item) => !item.forUpdation);
    console.log(inclusionBoxes);
  };

  const onReportProblem = (formVal) => {
    console.log(formVal);
  };

  // to come from dashboard with actions. onClick will be added in this lib
  const toolbarConfig = [
    // {
    //   name: "reportProblem",
    //   type: "button",
    //   label: ["Report Problem"],
    //   onClick: () => toggleToolbarModal("reportProblem"),
    //   action: onReportProblem,
    //   // modal content
    //   modalData: {
    //     content: [
    //       {
    //         name: "problem",
    //         type: "dropdown",
    //         label: ["Problem"],
    //         options: [{ label: "A", value: "a" }],
    //         enabled: true,
    //       },
    //       {
    //         name: "comment",
    //         type: "input",
    //         label: ["Comment"],
    //         enabled: true,
    //       },
    //       {
    //         name: "debugBucket",
    //         type: "radio",
    //         label: ["Debug Bucket"],
    //         options: ["Green", "Yellow", "Red"],
    //         enabled: true,
    //       },
    //     ],
    //   },
    //   enabled: true,
    // },
    // {
    //   name: "showProblem",
    //   type: "toggle",
    //   label: ["Hide Problem", "Show Problem"],
    //   onClick: () => toggleToolbarSwitch("showProblem"),
    //   action: () => {},
    //   enabled: true,
    // },
    {
      name: "viewInfo",
      type: "checkbox",
      label: ["View Info"],
      action: () => {},
      onClick: () => toggleToolbarCheckbox("viewInfo"),
      data: "options goes here",
      enabled: true,
    },
    {
      name: "inclusion",
      type: "toggle",
      label: ["Include", "Exclude"],
      onClick: () => toggleToolbarSwitch("inclusion"),
      action: () => {},
      enabled: true,
    },
    {
      name: "save",
      type: "button",
      label: ["Save"],
      action: handleInclusionSave, // from Parent
      // modal content
      enabled: true,
    },
  ];

  useEffect(() => {
    if (!Object.keys(toolbarState).length) {
      let obj = {};
      toolbarConfig.map((item) => (obj[item.name] = false));
      setToolbarState(obj);
    }
  }, [toolbarConfig]);

  const handleProductFilterChange = ({
    value,
    id,
    productFilter,
    dependentOn,
    currentFilter,
  }) => {
    setFilterValues((prev) => ({ ...prev, [id]: value }));

    const parentFilter = productFilter.find((item) => item.key === dependentOn);

    const childFilter = productFilter.find(
      (item) => item.key === currentFilter.child_filter
    );

    // add 'Other' value to sku dropdown when brand is selected
    if (childFilter) {
      setFilterValues((prev) => ({
        ...prev,
        [childFilter.label]: {
          label: "Other",
          value: 9000000,
        },
      }));
    }

    if (parentFilter && value.value !== 9000000) {
      setFilterValues((prev) => ({
        ...prev,
        [parentFilter.label]: value.parentOption,
      }));
    }
  };

  const resetFilters = () => {
    setFilterValues({});
    setStickerPrice("");
  };

  const saveFilters = () => {
    console.log({ ...filterValues, stickerPrice }, forUpdationBoxes);
    resetFilters();
    setForUpdationBoxes([]);

    // method to come from dashboard
  };

  const onTabChange = (val) => {
    setActiveTab(val);
  };

  useEffect(() => {
    if (!activeTab) {
      setActiveTab(tableTabs[0]);
    }
  }, [tableTabs]);

  useEffect(() => {
    resetComponent();
  }, [isTse]);

  const currentTable =
    tableData?.length && tableData.find((item) => item.label === activeTab);

  return (
    <>
      <ContainerDimensions>
        {({ width, height }) => (
          <div
            style={{
              padding: "10px",
              color: theme === "light" ? "rgba(0, 0, 0, 0.87)" : "#ffffff99",
              minHeight: "100vh",
              backgroundColor:
                theme !== "light" ? "rgb(30, 30, 43)" : "rgb(245, 245, 245)",
            }}
          >
            {toolbarState["viewInfo"] ? (
              <FixFacing
                theme={theme}
                selectedBoxes={selectedBoxes}
                forUpdationBoxes={forUpdationBoxes}
                fixFacingFilters={fixFacingFilters}
                handleProductFilterChange={handleProductFilterChange}
                filterValues={filterValues}
                resetFilters={resetFilters}
                saveFilters={saveFilters}
                stickerPrice={stickerPrice}
                setStickerPrice={setStickerPrice}
              />
            ) : null}
            <div style={{ fontSize: "10px", position: "absolute" }}>
              <div style={{}}>Version - {metadata.version}</div>
              <div style={{}}>
                Internal Version - {metadata.internalVersion}
              </div>
            </div>
            <div className="alignCenter">
              <div style={{ display: "flex", alignItems: "end" }}>
                <div>
                  <div>Date</div>
                  <input
                    value={filters.fl_dropdown_date}
                    onChange={(e) => {
                      setFilters({
                        ...filters,
                        fl_dropdown_date: e.target.value,
                      });
                    }}
                  />
                </div>
                <div>
                  <div>Category</div>
                  <input
                    value={filters.fl_category}
                    onChange={(e) => {
                      setFilters({
                        ...filters,
                        fl_category: e.target.value,
                      });
                    }}
                  />
                </div>
                <button
                  type="submit"
                  style={{ height: "20px" }}
                  onClick={handleSubmit}
                >
                  Search
                </button>
                <span style={{ marginLeft: 10 }}>
                  <label style={{ display: "flex", alignItems: "center" }}>
                    SE
                    <ToggleComponent
                      handleToggle={() => toggleTSE((isTse) => !isTse)}
                      isChecked={isTse}
                      name="tse-toggle"
                    />
                    TSE
                  </label>
                </span>
                <span style={{ marginLeft: 10 }}>
                  <label style={{ display: "flex", alignItems: "center" }}>
                    light
                    <ToggleComponent
                      handleToggle={() =>
                        setTheme((theme) =>
                          theme === "dark" ? "light" : "dark"
                        )
                      }
                      isChecked={theme === "dark"}
                      name="tse-toggle"
                    />
                    Dark
                  </label>
                </span>
              </div>
            </div>
            <div style={{ width: "100%" }}>
              {sessionData ? (
                sessionData.images.length > 0 ? (
                  <>
                    {isTse ? (
                      <Toolbar
                        // for theme
                        theme={theme}
                        showProblemToggle={true}
                        showInclusionToggle={true}
                        showReportProblem={true}
                        showInfoToggle={true}
                        toggleInclusion={toggleInclusion}
                        inclusion={inclusion}
                        onClickSave={onClickSave}
                        toggleInfo={toggleInfo}
                        toolbarConfig={toolbarConfig}
                        toolbarState={toolbarState}
                        isSaveDisabled={
                          toolbarState["viewInfo"] || !selectedBoxes.length
                        }
                      />
                    ) : null}
                    <ShelfImageDisplay
                      // for theme
                      theme={theme}
                      imagesSetWidth={imagesSetWidth}
                      setImagesSetWidth={setImagesSetWidth}
                      images={sessionData.images}
                      allBoxes={visibleBoxes}
                      boundingBoxes={imageBoundingBoxes}
                      selectedBoxes={selectedBoxes}
                      setSelectedBoxes={setSelectedBoxes}
                      onClickBoundingBox={onClickBoundingBox}
                      zoom={isZoomEnabled}
                      setScrollValue={setScrollValue}
                      scrolLeft={scrolLeft}
                      setShowAnchor={setShowAnchor}
                      setMinimapDraggableWidth={setMinimapDraggableWidth}
                      shelfWidth={width - 20}
                      onClickPolygon={onClickPolygon}
                      dynamicCheckboxes={dynamicCheckboxes}
                      enableZoom={enableZoom}
                      inclusion={inclusion}
                      toolbarState={toolbarState}
                      isTse={isTse}
                      forUpdationBoxes={forUpdationBoxes}
                    />

                    <div
                      className=" miniMap"
                      style={{ margin: "10px 0px 10px 0px" }}
                    >
                      <ErrorBoundary component={"Minimap"}>
                        <Minimap
                          // for theme
                          theme={theme}
                          showAnchor={showAnchor}
                          images={sessionData.images}
                          boundingBoxes={imageBoundingBoxes}
                          setMinPos={setMinPos}
                          minPos={minPos}
                          scrollValue={scrollValue}
                          setScrollLeft={setScrollLeft}
                          loading={loading}
                          minimapDraggableWidth={minimapDraggableWidth}
                          defaultAnchorPosition={defaultAnchorPosition}
                          setDefaultAnchorPosition={setDefaultAnchorPosition}
                          dynamicCheckboxes={dynamicCheckboxes}
                          shelfWidth={width - 20}
                          selectedBoxes={selectedBoxes}
                          forUpdationBoxes={forUpdationBoxes}
                          isTse={isTse}
                        />
                      </ErrorBoundary>
                    </div>

                    {tableData?.length ? (
                      <Table
                        // for theme
                        theme={theme}
                        width={width - 20}
                        height={height}
                        columnDefs={currentTable?.columns}
                        rowData={currentTable?.rows}
                        onRowSelect={onRowSelect}
                        visibleBoxes={visibleBoxes}
                        selectedVariants={selectedVariants}
                        toggleAllBoxes={toggleAllBoxes}
                        allVariantsSelected={allVariantsSelected}
                        showCropDetails={showCropDetails}
                        handleCheckBoxClicked={handleCheckBoxClicked}
                        dynamicCheckboxes={dynamicCheckboxes}
                        colorLegend={sessionData.color_legend}
                        store_explorer_settings={
                          sessionData.store_explorer_settings
                        }
                        imageBoundingBoxes={imageBoundingBoxes}
                        tabs={tableTabs}
                        onTabChange={onTabChange}
                        activeTab={activeTab}
                      />
                    ) : (
                      <Table
                        // for theme
                        theme={theme}
                        width={width - 20}
                        height={height}
                        columnDefs={tableData?.columns}
                        rowData={tableData?.rows}
                        onRowSelect={onRowSelect}
                        visibleBoxes={visibleBoxes}
                        selectedVariants={selectedVariants}
                        toggleAllBoxes={toggleAllBoxes}
                        allVariantsSelected={allVariantsSelected}
                        showCropDetails={showCropDetails}
                        handleCheckBoxClicked={handleCheckBoxClicked}
                        dynamicCheckboxes={dynamicCheckboxes}
                        colorLegend={sessionData.color_legend}
                        store_explorer_settings={
                          sessionData.store_explorer_settings
                        }
                        imageBoundingBoxes={imageBoundingBoxes}
                      />
                    )}
                  </>
                ) : (
                  <div className="alignCenter">No results found</div>
                )
              ) : (
                <div className="alignCenter">
                  {loading ? (
                    <img src={loader} height={100}></img>
                  ) : (
                    "Select filters"
                  )}
                </div>
              )}
            </div>
            {/* view info tooltip */}
            {!isTse ? (
              <DetailsTooltip
                theme={theme}
                cropDetails={showCropDetails}
                setCropDetails={setShowCropDetails}
              />
            ) : (
              toolbarState.viewInfo && (
                <DetailsTooltip
                  theme={theme}
                  isTse={isTse}
                  cropDetails={showCropDetails}
                  setCropDetails={setShowCropDetails}
                />
              )
            )}
          </div>
        )}
      </ContainerDimensions>
      <ImageViewer
        toggleModal={toggleModal}
        showModal={showModal}
        imageUrl={imageUrl}
      />
    </>
  );
};
export default ShelfVisualizer;
